import { ChangeDetectionStrategy, Component } from '@angular/core';
import { NavbarComponent } from '../../shared/components/navbar/navbar.component';
import { CurrencyPipe, NgFor } from '@angular/common';
import { Game } from '../../model/Game';
import { Transaction } from '../../model/Transaction';
import { DepositComponent } from '../deposit/deposit.component';
import {ConfirmationComponent} from "../../shared/components/confirmation/confirmation.component";

@Component({
  selector: 'app-homepage',
  standalone: true,
  imports: [NavbarComponent, CurrencyPipe, NgFor, DepositComponent, ConfirmationComponent],
  templateUrl: './home.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export default class HomeComponent {
  isDepositModalOpen = false;
  isDepositSuccessful = true;

  featuredGames: Game[] = [
    {
      id: '1',
      name: 'Poker',
      image: '/poker.webp',
    },
    {
      id: '2',
      name: 'Blackjack',
      image: '/blackjack.webp',
    },
    {
      id: '3',
      name: 'Slots',
      image: '/slots.webp',
    },
    {
      id: '4',
      name: 'Plinko',
      image: '/plinko.webp',
    },
    {
      id: '5',
      name: 'Liars Dice',
      image: '/liars-dice.webp',
    },
    {
      id: '6',
      name: 'Lootboxen',
      image: '/lootbox.webp',
    },
  ];

  allGames: Game[] = [...this.featuredGames];

  recentTransactions: Transaction[] = [
    {
      id: '1',
      type: 'Deposit',
      amount: 100.0,
      date: '2024-03-20',
    },
    {
      id: '2',
      type: 'Withdrawal',
      amount: -50.0,
      date: '2024-03-19',
    },
    {
      id: '3',
      type: 'Bonus',
      amount: 25.0,
      date: '2024-03-18',
    },
  ];

  openDepositModal() {
    this.isDepositModalOpen = true;
  }
  closeDepositModal() {
    this.isDepositModalOpen = false;
  }

  openDepositSuccessfulModal() {
    this.isDepositSuccessful = true;
  }
  closeDepositSuccessfulModal() {
    this.isDepositSuccessful = false;
  }
}
